@@ -40,7 +40,8 @@ constructCodelist <- function(x) {
 
 validateCodelist <- function(x) {
 
-  assertList(x, named = TRUE, class = c("numeric", "integer"))
+  assertList(x, named = TRUE,
+             class = c("numeric", "integer", "integer64"))
 
   for (nm in names(x)) {
     if (any(is.na(unique(x[[nm]])))) {
