@@ -340,3 +340,38 @@ test_that("test checkCohortRequirements", {
   expect_error(checkCohortRequirements("a"))
 
 })
+
+test_that("test error if attributes lost after class creation", {
+  person <- dplyr::tibble(
+    person_id = 1, gender_concept_id = 0, year_of_birth = 1990,
+    race_concept_id = 0, ethnicity_concept_id = 0
+  )
+  observation_period <- dplyr::tibble(
+    observation_period_id = 1, person_id = 1,
+    observation_period_start_date = as.Date("2000-01-01"),
+    observation_period_end_date = as.Date("2025-12-31"),
+    period_type_concept_id = 0
+  )
+  cdm <- cdmFromTables(
+    tables = list("person" = person, "observation_period" = observation_period),
+    cdmName = "test"
+  )
+
+  cdm <- insertTable(cdm, name = "cohort1", table = dplyr::tibble(
+    cohort_definition_id = 1, subject_id = 1,
+    cohort_start_date = as.Date(c("2020-01-01")),
+    cohort_end_date = as.Date(c("2020-01-10"))
+  ))
+  cdm$cohort1 <- newCohortTable(cdm$cohort1, .softValidation = TRUE)
+
+  expect_no_error(cdm$cohort1 |> dplyr::collect())
+
+  # remove cohort attrition attribute
+  attr(cdm$cohort1, "cohort_attrition") <- NULL
+  expect_error(cdm$cohort1 |> dplyr::collect())
+
+  # remove cohort set attribute
+  attr(cdm$cohort1, "cohort_set") <- NULL
+  expect_error(cdm$cohort1 |> dplyr::collect())
+
+  })
